@@ -141,6 +141,15 @@ async def django_sync_to_async_list(
     return django_instances
 
 
+@sync_to_async
+def django_sync_to_async_get(
+        django_instance,
+        param_to_get,
+):
+    param = getattr(django_instance, param_to_get)
+    return param
+
+
 def django_to_cache(
         django_model,
         redis_model,
@@ -221,7 +230,7 @@ async def django_instance_field_to_redis_value(
         redis_root,
         get_or_create_redis_model_from_django_model
 ):
-    django_field_value = getattr(django_instance, django_field.name)
+    django_field_value = await django_sync_to_async_get(django_instance, django_field.name)
     redis_value = django_field_value
     if django_field.__class__ == django_models.ForeignKey:
         if django_field_value is None:
@@ -260,7 +269,7 @@ async def django_instance_to_redis_params(
     redis_params = {}
     for i, django_field in enumerate(django_instance.__class__._meta.get_fields()):
         if not django_field.__class__.__name__.endswith('Rel'):
-            redis_param = await  django_instance_field_to_redis_value(
+            redis_param = await django_instance_field_to_redis_value(
                 django_instance,
                 django_field,
                 redis_root,
@@ -280,7 +289,7 @@ async def get_or_create_redis_instance_from_django_instance(
     redis_instance = redis_root.get(redis_model, django_id=django_instance.id)
     if not redis_instance:
         redis_dict = await django_instance_to_redis_params(django_instance, redis_root,
-                                                     get_or_create_redis_model_from_django_model)
+                                                           get_or_create_redis_model_from_django_model)
         redis_model(
             redis_root=redis_root,
             django_id=django_instance.id,
